# UrbanSim Defaults change log

#### 0.2 (2019-10-14)

- adds Python 3 support

#### 0.1.1 (2019-07-10)

- adds optional parameter to `utils.lcm_simulate()` for `alternative_ratio`

#### 0.1 (2019-06-19)

- initial release
